@@ -17,8 +17,8 @@ require ByteLoader;    # we just need its $VERSION
 no warnings;           # XXX
 
 @ISA       = qw(Exporter);
-@EXPORT_OK = qw(assemble_fh newasm endasm assemble asm maxopix maxsvix);
-$VERSION   = '1.12';
+our @EXPORT_OK = qw(assemble_fh newasm endasm assemble asm maxopix maxsvix);
+our $VERSION   = '1.13';
 
 use strict;
 my %opnumber;
@@ -114,9 +114,9 @@ sub B::Asmdata::PUT_strconst {
   my $arg = shift;
   my $str = uncstring($arg);
   if ( !defined($str) ) {
-    my @callstack = caller(1);
+    my @callstack = caller(3);
     error "bad string constant: '$arg', called from ".$callstack[3]
-      ." line:".$callstack[2];
+      ." line:".$callstack[2] unless $callstack[3] eq 'B::PADNAME::ix'; # empty newpadnx
     $str = '';
   }
   if ( $str =~ s/\0//g ) {
@@ -126,10 +126,10 @@ sub B::Asmdata::PUT_strconst {
   return $str . "\0";
 }
 
+# expects the string argument already on the "stack" (with depth 1, one sv)
 sub B::Asmdata::PUT_pvcontents {
-  error "Missing argument to PUT_pvcontents" if @_ < 1;
   my $arg = shift;
-  error "extraneous argument: $arg" if defined $arg;
+  error "extraneous argument to pvcontents: $arg" if defined $arg;
   return "";
 }
 
@@ -440,7 +440,7 @@ sub asm ($;$$) {
   if ( defined $_[1] ) {
     return
       if $_[1] eq "0"
-        and $_[0] !~ /^(?:ldsv|stsv|newsvx?|newpadlx|av_pushx?|av_extend|xav_flags)$/;
+        and $_[0] !~ /^(?:ldsv|stsv|newsvx?|newpad.*|av_pushx?|av_extend|xav_flags)$/;
     return if $_[1] eq "1" and $]>5.007 and $_[0] =~ /^(?:sv_refcnt)$/;
   }
   my ( $insn, $arg, $comment ) = @_;
